@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.200001';
+our $VERSION = '0.200002';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -69,13 +69,6 @@ has merge_strategy => (
     default => sub { $_[0]->merge_record_collisions ? 'toplevel' : 'none'; },
 );
 
-has node_count => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => '_build_node_count',
-);
-
 has remove_reserved_networks => (
     is      => 'ro',
     isa     => 'Bool',
@@ -469,7 +462,7 @@ MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory -
 
 =head1 VERSION
 
-version 0.200001
+version 0.200002
 
 =head1 SYNOPSIS
 
