@@ -12,9 +12,11 @@ use MaxMind::DB::Writer::Tree;
 use Net::Works::Address;
 use Net::Works::Network;
 use Scalar::Util qw( blessed );
+use Test::HexDifferences qw( eq_or_dump_diff );
 
 use Exporter qw( import );
 our @EXPORT_OK = qw(
+    insert_for_type
     make_tree_from_pairs
     ranges_to_data
     test_iterator_sanity
@@ -29,25 +31,31 @@ sub test_tree {
     my $desc         = shift;
     my $args         = shift;
 
-    my $tree = make_tree_from_pairs( $insert_pairs, $args );
+    for my $type (qw( network range )) {
 
-    _test_expected_data( $tree, $expect_pairs, $desc );
+        subtest "$desc - insert_$type " => sub {
+            my $tree = make_tree_from_pairs( $type, $insert_pairs, $args );
 
-    for my $raw (qw( 1.1.1.33 8.9.10.11 ffff::1 )) {
-        my $address = Net::Works::Address->new_from_string(
-            string  => $raw,
-            version => ( $raw =~ /::/ ? 6 : 4 ),
-        );
+            _test_expected_data( $tree, $expect_pairs, $desc );
 
-        is(
-            $tree->lookup_ip_address($address),
-            undef,
-            "The address $address is not in the tree - $desc"
-        );
+            for my $raw (qw( 1.1.1.33 8.9.10.11 ffff::1 )) {
+                my $address = Net::Works::Address->new_from_string(
+                    string  => $raw,
+                    version => ( $raw =~ /::/ ? 6 : 4 ),
+                );
+
+                is(
+                    $tree->lookup_ip_address($address),
+                    undef,
+                    "The address $address is not in the tree - $desc"
+                );
+            }
+        };
     }
 }
 
 sub make_tree_from_pairs {
+    my $type  = shift;
     my $pairs = shift;
     my $args  = shift;
 
@@ -63,15 +71,28 @@ sub make_tree_from_pairs {
 
     for my $pair ( @{$pairs} ) {
         my ( $network, @insert_args ) = @{$pair};
-        $network = Net::Works::Network->new_from_string( string => $network )
-            unless blessed $network;
 
-        $tree->insert_network( $network, @insert_args );
+        insert_for_type( $tree, $type, $network, @insert_args );
     }
 
     return $tree;
 }
 
+sub insert_for_type {
+    my $tree        = shift;
+    my $type        = shift;
+    my $network     = shift;
+    my @insert_args = @_;
+
+    if ( $type eq 'network' ) {
+        $tree->insert_network( $network, @insert_args );
+        return;
+    }
+    $network = Net::Works::Network->new_from_string( string => $network )
+        unless blessed $network;
+    $tree->insert_range( $network->first, $network->last, @insert_args );
+}
+
 sub _test_expected_data {
     my $tree   = shift;
     my $expect = shift;
@@ -208,8 +229,8 @@ sub test_freeze_thaw {
     $tree2->write_tree($fh);
     close $fh;
 
-    ok(
-        $tree1_output eq $tree2_output,
+    eq_or_dump_diff(
+        $tree1_output, $tree2_output,
         'output for tree is the same after freeze/thaw'
     );
 
